@@ -683,9 +683,9 @@ class RealTimeSignalEnsemblingParalleLauncher():
 
     def daily_apply_standard_mean_two_states_discretization_last_signal(self):
         signal_columns = [self.day_signal_mapping[me_sig] for me_sig in self.day_calib_signals_list]
-        prediction_index = self.day_signal_df.shape[0]
-        starting_train = prediction_index - 1 - self.daily_ia_lookback_window
-        stopping_train = prediction_index - 1
+        prediction_index = self.day_signal_df.shape[0]-1
+        starting_train = prediction_index - self.daily_ia_lookback_window
+        stopping_train = prediction_index
 
         local_signal_df = self.day_signal_df[signal_columns]
         full_y_true = self.day_signal_df['close'].pct_change().fillna(0.)
@@ -694,18 +694,22 @@ class RealTimeSignalEnsemblingParalleLauncher():
 
         y_train_true = full_y_true[starting_train:stopping_train]
         y_train_pred = np.mean(local_rolling_np, axis=1)
-
+        print('finding the best day discretization')
+        print(len(y_train_true))
+        print(len(y_train_pred))
         splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(
             y_train_pred, y_train_true)
         y_next_pred = local_signal_df.values[prediction_index, :].mean()
+        print('day continuous prediction ' + str(y_next_pred))
         y_next_pred_discrete = signal_utility.apply_discretization_two_states(y_next_pred, splitting_threshold)
+        print('day discrete prediction ' + str(y_next_pred_discrete))
         return y_next_pred_discrete
 
     def minutely_apply_standard_mean_two_states_discretization_last_signal(self):
         signal_columns = [self.minute_signal_mapping[me_sig] for me_sig in self.min_calib_signals_list]
-        prediction_index = self.minute_signal_df.shape[0]
-        starting_train = prediction_index - 1 - self.minutely_ia_lookback_window
-        stopping_train = prediction_index - 1
+        prediction_index = self.minute_signal_df.shape[0]-1
+        starting_train = prediction_index - self.minutely_ia_lookback_window
+        stopping_train = prediction_index
 
         local_signal_df = self.minute_signal_df[signal_columns]
         full_y_true = self.minute_signal_df['close'].pct_change().fillna(0.)
@@ -714,11 +718,14 @@ class RealTimeSignalEnsemblingParalleLauncher():
 
         y_train_true = full_y_true[starting_train:stopping_train]
         y_train_pred = np.mean(local_rolling_np, axis=1)
-
-        splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(
-            y_train_pred, y_train_true)
+        print('finding the best minute discretization')
+        print(len(y_train_true))
+        print(len(y_train_pred))
+        splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(y_train_pred, y_train_true)
         y_next_pred = local_signal_df.values[prediction_index, :].mean()
+        print('minute continuous prediction '+str(y_next_pred))
         y_next_pred_discrete = signal_utility.apply_discretization_two_states(y_next_pred, splitting_threshold)
+        print('minute discrete prediction '+str(y_next_pred_discrete))
         return y_next_pred_discrete
 
     def daily_apply_standard_mean_two_states_discretization(self, signals_df=None, s=21):
@@ -726,9 +733,9 @@ class RealTimeSignalEnsemblingParalleLauncher():
         signals_np = signals_df[day_signal_columns].values#[:, len(self.generic_columns):]
         full_y_true = signals_df['close'].pct_change().fillna(0.)
         y_pred_discretized = np.zeros(full_y_true.shape)
-        for row_index in range(s + 1, signals_np.shape[0]):
-            starting_train = row_index - 1 - s
-            stopping_train = row_index - 1
+        for row_index in range(s, signals_np.shape[0]):
+            starting_train = row_index - s
+            stopping_train = row_index
             prediction = row_index
             rolling_np = signals_np[starting_train:stopping_train, :]
             y_train_true = full_y_true[starting_train:stopping_train]
@@ -745,9 +752,9 @@ class RealTimeSignalEnsemblingParalleLauncher():
         signals_np = signals_df[minute_signal_columns].values#[:, len(self.generic_columns):]
         full_y_true = signals_df['close'].pct_change().fillna(0.)
         y_pred_discretized = np.zeros(full_y_true.shape)
-        for row_index in range(s + 1, signals_np.shape[0]):
-            starting_train = row_index - 1 - s
-            stopping_train = row_index - 1
+        for row_index in range(s, signals_np.shape[0]):
+            starting_train = row_index - s
+            stopping_train = row_index
             prediction = row_index
             rolling_np = signals_np[starting_train:stopping_train, :]
             y_train_true = full_y_true[starting_train:stopping_train]
@@ -1154,6 +1161,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         if  self.day_signal_np.shape[0]> self.daily_ia_lookback_window + 1:
             discrete_signals = self.daily_apply_standard_mean_two_states_discretization_last_signal()
         else :
+            print('trouble : not enough daily histo for proper quantization')
             return last_day_ts,np.nanmean(last_day_signals)
         return last_day_ts, discrete_signals
 
@@ -1170,6 +1178,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         if  self.minute_signal_np.shape[0]> self.minutely_ia_lookback_window + 1:
             discrete_signals = self.minutely_apply_standard_mean_two_states_discretization_last_signal()
         else :
+            print('trouble : not enough minute histo for proper quantization')
             return last_minute_ts, np.nanmean(last_minute_signals)
         return last_minute_ts, discrete_signals
 
