@@ -558,22 +558,34 @@ def find_best_two_states_discretization(y_pred, y, seed = 42, number_per_year =
         return sharpe_strat
 
     np.random.seed(seed)
-    # Optimize f
-    w__ = minimize(
-        f_to_optimize,
-        w0,
-        method='SLSQP',
-        #constraints=[const_sum],
-        bounds=const_ind
-    ).x
 
-    splitting_quantile_threshold = w__[0]
+    splitting_quantile_threshold = 0.5
+    trouble = False
+    try:
+        # Optimize f
+        w__ = minimize(
+            f_to_optimize,
+            w0,
+            method='SLSQP',
+            # constraints=[const_sum],
+            bounds=const_ind
+        ).x
+        splitting_quantile_threshold = w__[0]
+    except Exception as e:
+        trouble = True
+        ## we do nothting
+        #print(e)
+
+
+
     y_pred_discrete = discretize_two_states(y_pred, splitting_quantile_threshold=splitting_quantile_threshold)
     perf_df = signal_utility.reconstitute_prediction_perf(y_pred=y_pred_discrete, y_true=y,
                                                           transaction_cost=False,
                                                           print_turnover=False)
     sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=number_per_year, from_ret=True)
     sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=number_per_year, from_ret=True)
+    print('computing threshold value from quantile '+str(splitting_quantile_threshold))
+    print('computing threshold value with length '+len(y_pred))
     splitting_threshold = np.quantile(y_pred, splitting_quantile_threshold)
     return splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under
 
